@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2015-2016 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2015-2017 Jakub Wilk <jwilk@jwilk.net>
 #
 # This file is part of pdf2djvu.
 #
@@ -15,18 +15,19 @@
 
 from tools import (
     case,
-    re,
 )
 
+import re
+
 class test(case):
 
     # Bug: https://github.com/jwilk/pdf2djvu/issues/113
     # + fixed in 0.9.5 [1b262b90854cd3d5359cd7fdf6b72642b54c8f60]
     def test(self):
         r = self.pdf2djvu('--page-title-template', '{label}', quiet=False)
-        r.assert_(stderr=re('Warning: Ignoring duplicate page title: x\n'))
+        r.assert_(stderr=re.compile('Warning: Ignoring duplicate page title: x\n'))
         r = self.ls()
-        r.assert_(stdout=re(
+        r.assert_(stdout=re.compile(
             r'\n'
             r'\s*1\s+P\s+\d+\s+[\w.]+\s+T=x\n'
             r'\s*2\s+P\s+\d+\s+[\w.]+\n'
